@@ -1,10 +1,10 @@
 # @package      hubzero-submit-distributor
 # @file         JobKill.py
 # @author       Steven Clark <clarks@purdue.edu>
-# @copyright    Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# @copyright    Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -25,13 +25,15 @@
 # HUBzero is a registered trademark of HUBzero Foundation, LLC.
 #
 
-__version__ = '2.5.5'
+__version__ = '2.7.1'
 
 import sys
 import os
 import re
 import signal
 import subprocess
+import time
+import logging
 from errno import EPIPE
 
 from hubzero.submit.CommandParser    import CommandParser
@@ -42,14 +44,16 @@ class JobKill:
                 jobMonitorHost,
                 jobMonitorPort):
 
+      self.logger           = logging.getLogger(__name__)
       self.version          = __version__
       self.operationMode    = 0
       self.jobMonitorHost   = jobMonitorHost
       self.jobMonitorPort   = jobMonitorPort
       self.remoteJobMonitor = RemoteJobMonitor(jobMonitorHost,jobMonitorPort)
 
-      self.commandParser = None
-      self.killIds       = []
+      self.commandParser        = None
+      self.doubleDashTerminator = bool(os.getenv("DOUBLE_DASH_TERMINATOR",'0'))
+      self.killIds              = []
 
       self.hubUserId = os.getuid()
 
@@ -81,10 +85,9 @@ class JobKill:
          pass
 
 
-   def parseCommandArguments(self,
-                             doubleDashTerminator=False):
+   def parseCommandArguments(self):
       exitCode = 0
-      self.commandParser = CommandParser(doubleDashTerminator)
+      self.commandParser = CommandParser(self.doubleDashTerminator)
       self.commandParser.parseArguments(sys.argv[1:])
       self.operationMode = self.commandParser.getOperationMode()
 
@@ -138,7 +141,7 @@ class JobKill:
 
 
    @staticmethod
-   def killProcess(pid):
+   def __killProcess(pid):
       try:
          os.kill(pid,signal.SIGINT)
          for retry in range(0,12):
@@ -161,6 +164,6 @@ class JobKill:
       for killId in self.killIds:
          activeJobPid = self.remoteJobMonitor.queryUserActiveJobPid(self.hubUserId,killId)
          if activeJobPid:
-            self.killProcess(activeJobPid)
+            self.__killProcess(activeJobPid)
 
 
