@@ -1,10 +1,10 @@
 # @package      hubzero-submit-distributor
 # @file         JobStatus.py
 # @author       Steven Clark <clarks@purdue.edu>
-# @copyright    Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# @copyright    Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -25,13 +25,14 @@
 # HUBzero is a registered trademark of HUBzero Foundation, LLC.
 #
 
-__version__ = '2.5.5'
+__version__ = '2.7.1'
 
 import sys
 import os
 import re
 import signal
 import subprocess
+import logging
 from errno import EPIPE
 
 from hubzero.submit.CommandParser    import CommandParser
@@ -42,14 +43,16 @@ class JobStatus:
                 jobMonitorHost,
                 jobMonitorPort):
 
+      self.logger           = logging.getLogger(__name__)
       self.version          = __version__
       self.operationMode    = 0
       self.jobMonitorHost   = jobMonitorHost
       self.jobMonitorPort   = jobMonitorPort
       self.remoteJobMonitor = RemoteJobMonitor(jobMonitorHost,jobMonitorPort)
 
-      self.commandParser = None
-      self.statusIds     = []
+      self.commandParser        = None
+      self.doubleDashTerminator = bool(os.getenv("DOUBLE_DASH_TERMINATOR",'0'))
+      self.statusIds            = []
 
       self.hubUserId = os.getuid()
 
@@ -81,10 +84,9 @@ class JobStatus:
          pass
 
 
-   def parseCommandArguments(self,
-                             doubleDashTerminator=False):
+   def parseCommandArguments(self):
       exitCode = 0
-      self.commandParser = CommandParser(doubleDashTerminator)
+      self.commandParser = CommandParser(self.doubleDashTerminator)
       self.commandParser.parseArguments(sys.argv[1:])
       self.operationMode = self.commandParser.getOperationMode()
 
@@ -138,7 +140,7 @@ class JobStatus:
 
 
    @staticmethod
-   def natsort(l):
+   def __natsort(l):
       def tryfloat(s):
          try:
             return int(s)
@@ -174,11 +176,11 @@ class JobStatus:
          self.__writeToStdout("%-*s  %12s  %8s  %20s  %s\n" % (maximumRunNameLength,'RunName', \
                                                                'submitRun','Instance','Status','Location'))
          localJobIds = reportedJobs.keys()
-         self.natsort(localJobIds)
+         self.__natsort(localJobIds)
          for localJobId in localJobIds:
             if reportAllIds or (localJobId in self.statusIds):
                instanceIds = reportedJobs[localJobId].keys()
-               self.natsort(instanceIds)
+               self.__natsort(instanceIds)
                for instanceId in instanceIds:
                   runName,jobQueue,jobSite,jobStatus,jobStage = reportedJobs[localJobId][instanceId]
                   if jobQueue != '?':
