@@ -1,10 +1,10 @@
 # @package      hubzero-submit-distributor
 # @file         VenueMechanismGsiSsh.py
 # @author       Steven Clark <clarks@purdue.edu>
-# @copyright    Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# @copyright    Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -32,8 +32,9 @@ import stat
 import time
 import datetime
 import socket
+import logging
 
-from hubzero.submit.LogMessage             import logID as log
+from hubzero.submit.LogMessage             import getLogIDMessage as getLogMessage
 from hubzero.submit.JobStatistic           import JobStatistic
 from hubzero.submit.VenueMechanismCore     import VenueMechanismCore
 from hubzero.submit.RemoteBatchCONDOR      import RemoteBatchCONDOR
@@ -82,6 +83,7 @@ class VenueMechanismGsiSsh(VenueMechanismCore):
       VenueMechanismCore.__init__(self,timeHistoryLogs,siteInfo,managerInfo,remoteMonitors,
                                        isMultiCoreRequest,nCpus,nNodes,ppn)
 
+      self.logger                = logging.getLogger(__name__)
       self.venueMechanism        = 'gsissh'
       self.hubUserName           = hubUserName
       self.hubUserId             = hubUserId
@@ -187,11 +189,11 @@ class VenueMechanismGsiSsh(VenueMechanismCore):
             keyfamily = self.remoteUser.split(':')[1]
             self.remoteUser = self.hubUserName
             command = 'genuserpki ' + keyfamily
-            log("command = " + command)
+            self.logger.log(logging.INFO,getLogMessage("command = " + command))
             exitStatus,stdOutput,stdError = self.executeCommand(command)
             if not exitStatus:
                self.sshIdentityPath = stdOutput.strip()
-               log("IDENTITY = " + self.sshIdentityPath)
+               self.logger.log(logging.INFO,getLogMessage("IDENTITY = " + self.sshIdentityPath))
                updateKnownHosts = True
          elif self.remoteUser.startswith('USER'):
             self.remoteUser = self.hubUserName
@@ -202,7 +204,7 @@ class VenueMechanismGsiSsh(VenueMechanismCore):
                   command = 'update-known-hosts' + " " + self.gsiHost
                else:
                   command = 'update-known-hosts' + " " + self.venue
-               log("command = " + command)
+               self.logger.log(logging.INFO,getLogMessage("command = " + command))
                exitStatus,stdOutput,stdError = self.executeCommand(command)
                if not exitStatus:
                   self.sshBaseCommand = "ssh -T -x -a -i " + self.sshIdentityPath + " " + \
@@ -224,7 +226,7 @@ class VenueMechanismGsiSsh(VenueMechanismCore):
       exitCode    = 0
       scriptFiles = []
 
-      log("workingDirectory " + self.workingDirectory)
+      self.logger.log(logging.INFO,getLogMessage("workingDirectory " + self.workingDirectory))
       if   self.remoteBatchSystem == 'PBS':
          remoteAppScript = RemoteBatchAppScript(self.hubUserName,self.hubUserId,
                                                 self.runName,self.localJobId,self.instanceId,False,
@@ -396,8 +398,8 @@ class VenueMechanismGsiSsh(VenueMechanismCore):
             if self.remoteBatchSystem == 'SCRIPT':
                os.chmod(self.batchScriptPath,stat.S_IRWXU|stat.S_IRGRP|stat.S_IXGRP|stat.S_IROTH|stat.S_IXOTH)
          else:
-            log("could not open %s for writing" % (self.batchScriptPath))
-            self.__writeToStderr("could not open %s for writing\n" % (self.batchScriptPath))
+            self.logger.log(logging.ERROR,getLogMessage("could not open %s for writing" % (self.batchScriptPath)))
+            self._writeToStderr("could not open %s for writing\n" % (self.batchScriptPath))
             self.jobStatistics[0]['exitCode'] = 1
             exitCode = 1
 
@@ -409,8 +411,8 @@ class VenueMechanismGsiSsh(VenueMechanismCore):
             os.chmod(self.appScriptPath,stat.S_IRWXU|stat.S_IRGRP|stat.S_IXGRP|stat.S_IROTH|stat.S_IXOTH)
             scriptFiles.append(self.appScriptPath)
          else:
-            log("could not open %s for writing" % (self.appScriptPath))
-            self.__writeToStderr("could not open %s for writing\n" % (self.appScriptPath))
+            self.logger.log(logging.ERROR,getLogMessage("could not open %s for writing" % (self.appScriptPath)))
+            self._writeToStderr("could not open %s for writing\n" % (self.appScriptPath))
             self.jobStatistics[0]['exitCode'] = 1
             exitCode = 1
 
@@ -420,8 +422,8 @@ class VenueMechanismGsiSsh(VenueMechanismCore):
             fpNodes.write('\n'.join(nodeList)+'\n')
             fpNodes.close()
          else:
-            log("could not open %s for writing" % (self.nodeFilePath))
-            self.__writeToStderr("could not open %s for writing\n" % (self.nodeFilePath))
+            self.logger.log(logging.ERROR,getLogMessage("could not open %s for writing" % (self.nodeFilePath)))
+            self._writeToStderr("could not open %s for writing\n" % (self.nodeFilePath))
             self.jobStatistics[0]['exitCode'] = 1
             exitCode = 1
 
@@ -450,16 +452,18 @@ class VenueMechanismGsiSsh(VenueMechanismCore):
                                                    " \"" + self.receiveInput + " " + \
                                                                   self.venue + " " + \
                                                       remoteWorkingDirectory + " " + \
+                                                       self.scratchDirectory + " " + \
                                 self.timeHistoryLogs['timestampTransferred'] + "\""
             else:
                command = "cat " + stageInTarPath + " | " + self.sshBaseCommand + \
                                                    " \"" + self.receiveInput + " " + \
                                                       remoteWorkingDirectory + " " + \
+                                                       self.scratchDirectory + " " + \
                                 self.timeHistoryLogs['timestampTransferred'] + "\""
-            log("command = " + command)
+            self.logger.log(logging.INFO,getLogMessage("command = " + command))
             os.environ['X509_USER_PROXY'] = self.x509ProxyPath
             exitStatus,stdOutput,stdError = self.executeSSHCommand(command,"")
-            log(stdOutput)
+            self.logger.log(logging.INFO,getLogMessage(stdOutput))
          else:
             exitStatus = 1
             stdOutput  = ""
@@ -469,13 +473,19 @@ class VenueMechanismGsiSsh(VenueMechanismCore):
          self.filesSent = False
          self.jobStatistics[self.jobIndex]['exitCode'] = 11
 #        if stdOutput != "":
-#           stdFile = os.path.join(self.instanceDirectory,"%s_%s.stdout" % (self.localJobId,self.instanceId))
+#           if self.instanceId:
+#              stdFile = os.path.join(self.instanceDirectory,"%s_%s.stdout" % (self.runName,self.instanceId))
+#           else:
+#              stdFile = os.path.join(self.instanceDirectory,"%s.stdout" % (self.runName))
 #           fpStd = open(stdFile,'a')
 #           if fpStd:
 #              fpStd.write(stdOutput)
 #              fpStd.close()
          if stdError != "":
-            stdFile = os.path.join(self.instanceDirectory,"%s_%s.stderr" % (self.localJobId,self.instanceId))
+            if self.instanceId:
+               stdFile = os.path.join(self.instanceDirectory,"%s_%s.stderr" % (self.runName,self.instanceId))
+            else:
+               stdFile = os.path.join(self.instanceDirectory,"%s.stderr" % (self.runName))
             fpStd = open(stdFile,'a')
             if fpStd:
                fpStd.write(stdError)
@@ -494,7 +504,7 @@ class VenueMechanismGsiSsh(VenueMechanismCore):
                command = self.sshBaseCommand + " " + self.batchScriptPath
             else:
                command = self.sshBaseCommand + " " + self.appScriptPath
-            log("command = " + command)
+            self.logger.log(logging.INFO,getLogMessage("command = " + command))
             exitStatus,stdOutput,stdError = self.executeCommand(command,True)
             self.jobSubmitted = True
             self.jobStatistics[self.jobIndex]['exitCode'] = exitStatus
@@ -506,6 +516,7 @@ class VenueMechanismGsiSsh(VenueMechanismCore):
             if self.addVenueToBatchCommand:
                commandArgs.append(self.venue)
             commandArgs.append(remoteWorkingDirectory)
+            commandArgs.append(self.scratchDirectory)
             if self.batchScriptPath != "":
                commandArgs.append(self.batchScriptPath)
             else:
@@ -517,7 +528,7 @@ class VenueMechanismGsiSsh(VenueMechanismCore):
                commandArgs.append(self.executable)
             command = self.sshBaseCommand + " \"" + ' '.join(commandArgs) + "\""
 
-            log("command = " + command)
+            self.logger.log(logging.INFO,getLogMessage("command = " + command))
             os.environ['X509_USER_PROXY'] = self.x509ProxyPath
             exitStatus,stdOutput,stdError = self.executeSSHCommand(command,"",True)
             self.jobSubmitted = True
@@ -528,6 +539,7 @@ class VenueMechanismGsiSsh(VenueMechanismCore):
             if self.addVenueToBatchCommand:
                commandArgs.append(self.venue)
             commandArgs.append(remoteWorkingDirectory)
+            commandArgs.append(self.scratchDirectory)
             commandArgs.append(os.path.join('.',os.path.basename(self.batchScriptPath)))
             if self.logUserRemotely:
                commandArgs.append(self.hubUserName)
@@ -535,12 +547,12 @@ class VenueMechanismGsiSsh(VenueMechanismCore):
                commandArgs.append(self.localJobId.lstrip('0') + '_' + self.instanceId)
                commandArgs.append(self.executable)
             command = self.sshBaseCommand + " \"" + ' '.join(commandArgs) + "\""
-            log("command = " + command)
+            self.logger.log(logging.INFO,getLogMessage("command = " + command))
             os.environ['X509_USER_PROXY'] = self.x509ProxyPath
             exitStatus,stdOutput,stdError = self.executeSSHCommand(command,"")
             if not exitStatus:
                remoteJobId = stdOutput.strip()
-               log("remoteJobId = " + remoteJobId)
+               self.logger.log(logging.INFO,getLogMessage("remoteJobId = " + remoteJobId))
                try:
                   if   self.remoteBatchSystem == 'PBS':
                      self.remoteJobIdNumber = remoteJobId.split('.')[0]
@@ -577,13 +589,19 @@ class VenueMechanismGsiSsh(VenueMechanismCore):
 
       if not self.jobSubmitted:
          if stdOutput != "":
-            stdFile = os.path.join(self.instanceDirectory,"%s_%s.stdout" % (self.localJobId,self.instanceId))
+            if self.instanceId:
+               stdFile = os.path.join(self.instanceDirectory,"%s_%s.stdout" % (self.runName,self.instanceId))
+            else:
+               stdFile = os.path.join(self.instanceDirectory,"%s.stdout" % (self.runName))
             fpStd = open(stdFile,'a')
             if fpStd:
                fpStd.write(stdOutput)
                fpStd.close()
          if stdError != "":
-            stdFile = os.path.join(self.instanceDirectory,"%s_%s.stderr" % (self.localJobId,self.instanceId))
+            if self.instanceId:
+               stdFile = os.path.join(self.instanceDirectory,"%s_%s.stderr" % (self.runName,self.instanceId))
+            else:
+               stdFile = os.path.join(self.instanceDirectory,"%s.stderr" % (self.runName))
             fpStd = open(stdFile,'a')
             if fpStd:
                fpStd.write(stdError)
@@ -623,20 +641,26 @@ class VenueMechanismGsiSsh(VenueMechanismCore):
                command = self.sshBaseCommand + " \"" + self.transmitResults + " " + \
                                                     remoteWorkingDirectory + "\"" + \
                                                " | tar xzmf - --ignore-case --exclude '*hub-proxy.*' -C " + self.instanceDirectory
-            log("command = " + command)
+            self.logger.log(logging.INFO,getLogMessage("command = " + command))
             os.environ['X509_USER_PROXY'] = self.x509ProxyPath
             exitStatus,stdOutput,stdError = self.executeSSHCommand(command,"")
-            log(stdOutput)
+            self.logger.log(logging.INFO,getLogMessage(stdOutput))
             if exitStatus:
                self.jobStatistics[self.jobIndex]['exitCode'] = 12
 #              if stdOutput != "":
-#                 stdFile = os.path.join(self.instanceDirectory,"%s_%s.stdout" % (self.localJobId,self.instanceId))
+#                 if self.instanceId:
+#                    stdFile = os.path.join(self.instanceDirectory,"%s_%s.stdout" % (self.runName,self.instanceId))
+#                 else:
+#                    stdFile = os.path.join(self.instanceDirectory,"%s.stdout" % (self.runName))
 #                 fpStd = open(stdFile,'a')
 #                 if fpStd:
 #                    fpStd.write(stdOutput)
 #                    fpStd.close()
                if stdError != "":
-                  stdFile = os.path.join(self.instanceDirectory,"%s_%s.stderr" % (self.localJobId,self.instanceId))
+                  if self.instanceId:
+                     stdFile = os.path.join(self.instanceDirectory,"%s_%s.stderr" % (self.runName,self.instanceId))
+                  else:
+                     stdFile = os.path.join(self.instanceDirectory,"%s.stderr" % (self.runName))
                   fpStd = open(stdFile,'a')
                   if fpStd:
                      fpStd.write(stdError)
@@ -652,12 +676,19 @@ class VenueMechanismGsiSsh(VenueMechanismCore):
             remoteWorkingDirectory = self.workingDirectory.replace('$','\$')
             if self.jobSubmitted:
                if self.addVenueToBatchCommand:
-                  command = self.sshBaseCommand + " \"" + self.cleanupJob + " " + self.venue + " " + remoteWorkingDirectory + "\""
+                  command = self.sshBaseCommand + " \"" + self.cleanupJob + " " + \
+                                                               self.venue + " " + \
+                                                   remoteWorkingDirectory + " " + \
+                                                    self.scratchDirectory + " " + \
+                                                   self.remoteBatchSystem + "\""
                else:
-                  command = self.sshBaseCommand + " \"" + self.cleanupJob + " " + remoteWorkingDirectory + "\""
-               log("command = " + command)
+                  command = self.sshBaseCommand + " \"" + self.cleanupJob + " " + \
+                                                   remoteWorkingDirectory + " " + \
+                                                    self.scratchDirectory + " " + \
+                                                   self.remoteBatchSystem + "\""
+               self.logger.log(logging.INFO,getLogMessage("command = " + command))
                os.environ['X509_USER_PROXY'] = self.x509ProxyPath
-               log(self.executeSSHCommand(command,"")[1])
+               self.logger.log(logging.INFO,getLogMessage(self.executeSSHCommand(command,"")[1]))
 
          if self.batchScriptPath:
             if os.path.isfile(self.batchScriptPath):
@@ -687,9 +718,9 @@ class VenueMechanismGsiSsh(VenueMechanismCore):
             command = self.sshBaseCommand + " \"" + self.killBatchJob + " " + \
                                                self.remoteJobIdNumber + " " + \
                                                self.remoteBatchSystem + "\""
-         log("command = " + command)
+         self.logger.log(logging.INFO,getLogMessage("command = " + command))
          os.environ['X509_USER_PROXY'] = self.x509ProxyPath
-         log(self.executeSSHCommand(command,"")[1])
+         self.logger.log(logging.INFO,getLogMessage(self.executeSSHCommand(command,"")[1]))
       elif self.remoteBatchSystem == 'SCRIPT' and self.childPid != 0:
 #        log("Send TERM to child script process %d" % (self.childPid))
 #        os.kill(childPid,signalNumber.SIGTERM)
@@ -697,12 +728,12 @@ class VenueMechanismGsiSsh(VenueMechanismCore):
             command = self.sshBaseCommand + " pkill -TERM -f " + os.path.basename(self.batchScriptPath)
          else:
             command = self.sshBaseCommand + " pkill -TERM -f " + os.path.basename(self.appScriptPath)
-         log("command = " + command)
+         self.logger.log(logging.INFO,getLogMessage("command = " + command))
          os.environ['X509_USER_PROXY'] = self.x509ProxyPath
-         log(self.executeSSHCommand(command,"")[1])
+         self.logger.log(logging.INFO,getLogMessage(self.executeSSHCommand(command,"")[1]))
 
       maximumJobIndex = max(self.jobStatistics.keys())
-      self.jobStatistics[maximumJobIndex]['exitCode'] = 1 << 8 | signalNumber
+      self.jobStatistics[maximumJobIndex]['exitCode'] = 1 << 7 | signalNumber
 
       self.scriptsKilled = True
 
